@@ -1032,18 +1032,18 @@ bool LCHMFileImpl::parseFileAndFillArray( const TQString & file, QT34VECTOR< LCH
 			TQString name_pattern = "name=", value_pattern = "value=";
 			TQString pname, pvalue;
 
-			if ( (offset = tag.find (name_pattern, 0, FALSE)) == -1 )
+			if ( (offset = tag.find (name_pattern, 0, false)) == -1 )
 				tqFatal ("LCHMFileImpl::ParseAndFillTopicsTree: bad <param> tag '%s': no name=\n", tag.ascii());
 
 			// offset+5 skips 'name='
-			offset = findStringInQuotes (tag, offset + name_pattern.length(), pname, TRUE, FALSE);
+			offset = findStringInQuotes (tag, offset + name_pattern.length(), pname, true, false);
 			pname = pname.lower();
 
-			if ( (offset = tag.find (value_pattern, offset, FALSE)) == -1 )
+			if ( (offset = tag.find (value_pattern, offset, false)) == -1 )
 				tqFatal ("LCHMFileImpl::ParseAndFillTopicsTree: bad <param> tag '%s': no value=\n", tag.ascii());
 
 			// offset+6 skips 'value='
-			findStringInQuotes (tag, offset + value_pattern.length(), pvalue, FALSE, TRUE);
+			findStringInQuotes (tag, offset + value_pattern.length(), pvalue, false, true);
 
 			//tqDebug ("<param>: name '%s', value '%s'", pname.ascii(), pvalue.ascii());
 
