@@ -31,7 +31,7 @@
 */
 class KCHMBookmarkWindow : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		KCHMBookmarkWindow(TQWidget *parent = 0, const char *name = 0);
