@@ -30,7 +30,7 @@
 */
 class KCHMContentsWindow : public KQListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
     	KCHMContentsWindow( TQWidget *parent = 0, const char *name = 0 );
