@@ -30,7 +30,7 @@
 */
 class KCHMDialogChooseUrlFromList : public TQDialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     KCHMDialogChooseUrlFromList (const TQStringList& urls, const TQStringList& titles, TQWidget* parent);
