@@ -35,7 +35,7 @@ namespace QtAs { class Index; };
 
 class KCHMSearchEngine : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 			
 	public:
