@@ -64,7 +64,7 @@ TQDataStream &operator<<( TQDataStream &s, const Document &l );
 
 class Index : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 	public:
 		struct Entry
