@@ -33,7 +33,7 @@
 */
 class KCHMSearchAndViewToolbar : public TQToolBar
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		KCHMSearchAndViewToolbar (KCHMMainWindow *parent);
