@@ -36,7 +36,7 @@ class KCHMSearchEngine;
 
 class KCHMClickableLabel : public TQLabel
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		KCHMClickableLabel( const TQString& label, TQWidget * parent )
@@ -54,7 +54,7 @@ class KCHMClickableLabel : public TQLabel
 
 class KCHMSearchWindow : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		KCHMSearchWindow ( TQWidget * parent = 0, const char * name = 0, WFlags f = 0 );
