@@ -17,7 +17,9 @@
  
 #include "kchmsetupdialog_impl.h"
 #include "kchmsetupdialog_impl.moc"
+#if defined(USE_KDE)
 #include <tdeapplication.h>
+#endif
 
 KCHMSetupDialog_impl::KCHMSetupDialog_impl(TQWidget* parent, const char* name, bool modal, WFlags fl)
     : KCHMSetupDialog(parent, name, modal, fl)
@@ -26,6 +28,7 @@ KCHMSetupDialog_impl::KCHMSetupDialog_impl(TQWidget* parent, const char* name, b
 
 void KCHMSetupDialog_impl::slotShowHelp()
 {
+#if defined(USE_KDE)
   kapp->invokeHelp();
+#endif
 }
-
