@@ -22,10 +22,10 @@
 
 class KCHMSetupDialog_impl : public KCHMSetupDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
-    KCHMSetupDialog_impl( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+    KCHMSetupDialog_impl( TQWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0 );
 
 public slots:
     void slotShowHelp();
